@@ -8,11 +8,12 @@
 @License :   Apache License 2.0 
 """
 
+from typing import List
 from torch.utils.data import Dataset
 
 
 class ClientDataset(Dataset):
-    def __init__(self, dataset, data_dict) -> None:
+    def __init__(self, dataset, data_dict: List) -> None:
         super().__init__()
         self.dataset = dataset
         self.data_dict = data_dict
